@@ -6,8 +6,6 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-from __future__ import absolute_import
-
 import json
 import logging
 
@@ -24,7 +22,7 @@ BASE_FEATURES = ("checksum", "extents")
 ALL_FEATURES = BASE_FEATURES + ("flush", "zero")
 
 
-class Handler(object):
+class Handler:
     """
     Handle requests for the /images/ resource.
     """
