@@ -308,9 +308,10 @@ def test_upload_shallow(srv, nbd_server, tmpdir, base_fmt):
     qemu_img.compare(
         src_base, dst_base, format1=base_fmt, format2=base_fmt, strict=False)
 
-    # Compare allocation if we use recent enough qemu-nbd reporting holes in
-    # raw images.
-    if base_fmt == "qcow2" or qemu_nbd.version() > (6, 0, 0):
+    # Comparing allocation is not possible with raw format since qemu-nbd does
+    # not report allocation for raw images, so we treat unallocated areas as
+    # zero area instead of a hole.
+    if base_fmt == "qcow2":
         qemu_img.compare(
             src_base, dst_base, format1=base_fmt, format2=base_fmt,
             strict=True)
@@ -338,8 +339,8 @@ def test_upload_shallow(srv, nbd_server, tmpdir, base_fmt):
     qemu_img.compare(
         src_top, dst_top, format1="qcow2", format2="qcow2", strict=False)
 
-    # Compare allocation - nice to have.
-    if base_fmt == "qcow2" or qemu_nbd.version() > (6, 0, 0):
+    # Compare allocation for qcow2 chain - nice to have.
+    if base_fmt == "qcow2":
         qemu_img.compare(
             src_top, dst_top, format1="qcow2", format2="qcow2", strict=True)
 
@@ -430,7 +431,6 @@ def test_download_shallow(srv, nbd_server, tmpdir, base_fmt):
 
     nbd_server.image = src_base
     nbd_server.fmt = base_fmt
-    nbd_server.shared = 8
     nbd_server.start()
 
     url = prepare_transfer(srv, nbd_server.sock.url(), size=size)
@@ -450,7 +450,7 @@ def test_download_shallow(srv, nbd_server, tmpdir, base_fmt):
         src_base, dst_base, format1=base_fmt, format2=base_fmt, strict=False)
 
     # And allocation - nice to have.
-    if base_fmt == "qcow2" or qemu_nbd.version() > (6, 0, 0):
+    if base_fmt == "qcow2" or qemu_nbd.version() >= (6, 0, 0):
         qemu_img.compare(
             src_base, dst_base, format1=base_fmt, format2=base_fmt,
             strict=True)
@@ -460,7 +460,6 @@ def test_download_shallow(srv, nbd_server, tmpdir, base_fmt):
     nbd_server.image = src_top
     nbd_server.fmt = "qcow2"
     nbd_server.backing_chain = False
-    nbd_server.shared = 8
     nbd_server.start()
 
     url = prepare_transfer(srv, nbd_server.sock.url(), size=size)
