@@ -10,9 +10,9 @@ import json
 
 import pytest
 
-from ovirt_imageio import config
-from ovirt_imageio import server
-from ovirt_imageio import version
+from ovirt_imageio._internal import config
+from ovirt_imageio._internal import server
+from ovirt_imageio._internal import version
 
 from . import http
 
